Skip to contents

Footprint data of one motif across groups

Usage

accFootprintData(
  tfbs,
  ins,
  expected,
  smooth = 5L,
  flankNorm = 50,
  ignoreStrand = TRUE
)

Arguments

tfbs

A GRanges of binding sites, prepared with prepareTFBS.

ins

A named list of insertion site GRanges.

expected

A named list of expected profiles with the columns x and w, or a single profile used for all.

smooth

Width of the running mean applied to the profiles.

flankNorm

Width of the flanking window used for matching.

ignoreStrand

If TRUE, strand information is ignored.

Value

A data.table with the columns x, avg_ins, type and group, or NULL.

Examples

if (FALSE) { # \dontrun{
accFootprintData(tfbs, insList, expectedList)
} # }