Skip to contents

The insertions of one sample are read at a time, so the memory cost is that of a single sample.

Usage

accObservedMatrix(files, tfbs, samples, ignoreStrand = TRUE)

Arguments

files

Paths of the per sample insertion site files.

tfbs

A named list of prepared binding sites.

samples

Sample identifiers, used as column names.

ignoreStrand

If TRUE, strand information is ignored.

Value

A matrix of motifs by samples.

Examples

if (FALSE) { # \dontrun{
accObservedMatrix(files, tfbs, samples)
} # }