Skip to contents

The total width of the bin is the denominator, so bases without an insertion count as zero.

Usage

addGCBintoAccessome(ins, gcdist, ignoreStrand = TRUE)

Arguments

ins

A GRanges of insertion sites.

gcdist

A GRanges of the genome wide GC distribution.

ignoreStrand

If TRUE, strand information is ignored.

Value

A matrix of GC bins and their insertion density.

Examples

if (FALSE) { # \dontrun{
addGCBintoAccessome(ins, gc_dist)
} # }