Skip to contents

One column per motif, the observed profiles on top and the corrected ones below.

Usage

plotAccFootprintGrid(
  profiles,
  tfbs,
  colors,
  method = "division",
  flankNorm = 30L,
  plotWindow = 200L,
  corrected = "bias corrected"
)

Arguments

profiles

A named list of footprint data tables.

tfbs

A named list of prepared binding sites, used for the site counts in the titles.

colors

Named vector of group colours.

method

Either "substraction" or "division".

flankNorm

Width of the flanking window used for normalisation.

plotWindow

Half width of the plotted window.

corrected

Label of the corrected row.

Value

A patchwork object.

Examples

if (FALSE) { # \dontrun{
plotAccFootprintGrid(profiles, tfbs, colors)
} # }