Skip to contents

Observed and expected profile of one motif in one sample

Usage

plotExpectedAccFootprint(
  motif,
  tf_bindsites,
  ins,
  sample_name = NULL,
  gc_dist,
  gcfreqs,
  enhancer = NULL,
  ignoreStrand = TRUE,
  smooth = 5L,
  returnPlotData = FALSE
)

Arguments

motif

Motif name.

tf_bindsites

A GRangesList of binding site positions.

ins

A GRanges of insertion sites.

sample_name

Optional sample label.

gc_dist

A GRanges of the genome wide GC distribution.

gcfreqs

A list of GC bin frequency tables.

enhancer

Optional GRanges restricting the sites.

ignoreStrand

If TRUE, strand information is ignored.

smooth

Width of the running mean applied to the profiles.

returnPlotData

If TRUE, the plot data is returned as well.

Value

A ggplot object, or a list with the plot and its data.

Examples

if (FALSE) { # \dontrun{
plotExpectedAccFootprint("CTCF", tf_bindsites, ins,
    gc_dist = gc_dist, gcfreqs = gcfreqs)
} # }