Skip to contents

Only the plotted curves depend on this. The deviation is a ratio of the centre over the flanks, so it is unchanged by the scale.

Usage

scaleToFlank(exp_profile, obs_profile, flankNorm = 50)

Arguments

exp_profile

A data.table with the columns x and w.

obs_profile

A data.table with the columns x and avg_ins.

flankNorm

Width of the flanking window used for matching.

Value

A data.table with the columns x and avg_ins.

Examples

if (FALSE) { # \dontrun{
scaleToFlank(expProfile, obsProfile)
} # }