Observed and expected profile of one motif in one sample
Source:R/footprints.R
plotExpectedAccFootprint.RdObserved and expected profile of one motif in one sample
Usage
plotExpectedAccFootprint(
motif,
tf_bindsites,
ins,
sample_name = NULL,
gc_dist,
gcfreqs,
enhancer = NULL,
ignoreStrand = TRUE,
smooth = 5L,
returnPlotData = FALSE
)Arguments
- motif
Motif name.
- tf_bindsites
A
GRangesListof binding site positions.- ins
A
GRangesof insertion sites.- sample_name
Optional sample label.
- gc_dist
A
GRangesof the genome wide GC distribution.- gcfreqs
A
listof GC bin frequency tables.- enhancer
Optional
GRangesrestricting the sites.- ignoreStrand
If TRUE, strand information is ignored.
- smooth
Width of the running mean applied to the profiles.
- returnPlotData
If TRUE, the plot data is returned as well.